Files
bitvid/tests/visual
google-labs-jules[bot]andPR0M3TH3AN a4f371b7fc perf: parallelize DM decryption
Refactors `listDirectMessages` to use `Promise.all` for parallel decryption, reducing execution time significantly (benchmark: ~1021ms -> ~14ms for 100 messages).

Also fixes CI stability:
- Fix race condition in `overlay-layers.spec.ts` visual test.
- Fix environment conflicts in unit tests.
- Add `_redirects` for Netlify.

Co-authored-by: PR0M3TH3AN <[email protected]>
2026-01-30 23:23:31 +00:00
..